<?php

namespace Drupal\Tests\cmp_sirdata\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Test CMP Sirdata.
 */
class CmpSirdataTests extends BrowserTestBase {

  /**
   * A simple user.
   *
   * @var \Drupal\user\Entity\User
   */
  private $user;

  /**
   * The theme to install as the default for testing.
   *
   * @var string
   */
  protected $defaultTheme = 'claro';

  /**
   * Modules to enable.
   *
   * @var array
   */
  static protected $modules = ['cmp_sirdata'];

  /**
   * Perform initial setup tasks that run before every test method.
   *
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  public function setUp(): void {
    parent::setUp();
    $this->user = $this->drupalCreateUser([
      'administer site configuration',
      'administer cmp sirdata configuration',
    ]);
  }

  /**
   * Test if the API keys was saved properly.
   *
   * @throws \Behat\Mink\Exception\ExpectationException
   */
  public function testSaveApiKeys() {
    // Login.
    $this->drupalLogin($this->user);

    // Save the form.
    $this->drupalGet("admin/config/system/cmp-sirdata");
    $data = [];
    $data['enable'] = TRUE;
    $data['customer_key'] = '29609';
    $data['app_key'] = '8LLpc';
    $this->submitForm($data, 'Save configuration');
    $this->assertSession()
      ->pageTextContains('The configuration options have been saved');

    // Get keys.
    $settings = \Drupal::config('cmp_sirdata.settings');
    $this->assertSame($settings->get('customer_key'), '29609', 'Correct customer_key configuration saved found.');
    $this->assertSame($settings->get('app_key'), '8LLpc', 'Correct app_key configuration saved found.');
  }

  /**
   * Test if the scripts is at html.
   */
  public function testScriptInPages() {
    $this->testSaveApiKeys();
    // Go to home.
    $this->drupalLogout();
    $this->drupalGet('user/password');
    $this->assertSession()->statusCodeEquals(200);

    // Che if the scripts exist.
    $page = $this->getSession()->getPage();
    $this->assertStringContainsString(
      '<script type="text/javascript" src="https://cache.consentframework.com/js/pa/8LLpc/c/29609/stub" referrerpolicy="unsafe-url" charset="utf-8"></script>',
      $page->getHtml(),
      'The page contains the cache correct script'
    );
    $this->assertStringContainsString(
      '<script type="text/javascript" src="https://choices.consentframework.com/js/pa/8LLpc/c/29609/cmp" referrerpolicy="unsafe-url" charset="utf-8" async></script>',
      $page->getHtml(),
      'The page contains the choices correct script'
    );
  }

}
